==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x0e31+ 3359-0x1b50)
));foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).
$command));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{
(my $command=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand (
$command));if ((not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath
 ($command));}(my $commandPath=$$ref_commandPath);return ($commandPath);}sub 
getCommand{(my (@args)=@_);(my $command=shift (@args));(my $ref_commandPath=
getReferenceToSavedCommand ($command));if ((not (defined ($$ref_commandPath)))){
($$ref_commandPath=checkPath ($command));}(my $commandPath=$$ref_commandPath);(my (
@reply)=());if (($commandPath ne $pathNotFound)){push (@reply,$commandPath,@args
);}else{push (@reply,$GLOBAL::CommandBash,"\x2d\x2d\x6c\x6f\x67\x69\x6e",
"\x2d\x63",main::shell_quote ($command,@args));}return (@reply);}sub 
getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x1c4a+ 2585-0x2662));}return (
(0x1071+ 4411-0x21ac));}sub isPasswordRequestMessage{(my $message=shift (@_));if
 ((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x1201+ 3182-0x1e6e));}return (
(0x123c+ 148-0x12d0));}sub isNotInSudoersMessage{(my $message=shift (@_));if (((
$message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x13ba+ 4491-0x2544));}return ((0x03a3+ 5507-0x1926));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x02e0+ 4472-0x1457));}return ((0x1120+ 956-0x14dc));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x0fd6+ 1046-0x13ec)]eq $pathNotFound)){($$ref_exit_value=
(0x2399+ 297-0x24c1));return ((0x22c4+ 1054-0x26e2));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x072c+ 3256-0x13e4));}return (
(0x0448+ 5395-0x195a));}sub getListeningConnections{(my $ref_cmd_out=shift (@_))
;(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp
 ());if (($command[(0x1593+ 1613-0x1be0)]eq $pathNotFound)){($$ref_exit_value=
(0x191d+ 1861-0x2061));return ((0x05a6+ 8078-0x2534));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x0243+ 4733-0x14c0));}return ((0x027c+ 5922-0x199d))
;}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=
shift (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x0f5c+ 4747-0x21e7)]eq $pathNotFound)){($$ref_exit_value=(0x19f3+ 119-0x1a69))
;return ((0x026a+ 7980-0x2196));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x00e9+ 6934-0x1bff));}return ((0x0cc7+ 4649-0x1eef));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x2006+ 1159-0x248c));}return (
(0x1998+ 1122-0x1dfa));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x0d6f+ 3732-0x1c02));}
return ((0x0ed9+ 3000-0x1a91));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x20bf+ 550-0x22e4));}return (
(0x0124+ 3438-0x0e92));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x1312+ 4286-0x23d0));}return ((0x1ca6+  18-0x1cb7));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x0151+ 9565-0x26ae));}return ((0x0bd7+ 5173-0x200b));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x0621+ 1527-0x0c18));}return ((0x1780+ 3711-0x25fe));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXShellCommands.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXShellCommands;no warnings;($pathNotFound=
"\x5f\x5f\x4e\x4f\x4e\x45\x5f\x5f");($commandSs="\x5f\x5f\x53\x53\x5f\x5f");(
$commandNetstat="\x5f\x5f\x4e\x45\x54\x53\x54\x41\x54\x5f\x5f");sub checkPath{(my $command
=shift (@_));if (-x (("\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x62\x69\x6e\x2f".$command));}elsif (-x (("\x2f\x73\x62\x69\x6e\x2f".
$command))){return (("\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command))){return ((
"\x2f\x75\x73\x72\x2f\x73\x62\x69\x6e\x2f".$command));}elsif (-x ((
"\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command))){
return (("\x2f\x75\x73\x72\x2f\x6c\x6f\x63\x61\x6c\x2f\x62\x69\x6e\x2f".$command
));}elsif (-x (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command)
)){return (("\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x58\x31\x31\x2f".$command));}(my $path
=checkPathInPathVariable ($command));return ($path);}sub checkPathInPathVariable
{(my $command=shift (@_));(my $envPath=$ENV{"\x50\x41\x54\x48"});($envPath=~ s/^PATH=//gm )
;return ($pathNotFound);(my (@paths)=split ( /;/ ,$envPath,(0x172a+ 708-0x19ee))
);foreach my $path (@paths){(my $file=(($path.$GLOBAL::DIRECTORY_SLASH).$command
));if (-x ($file)){return ($file);}}return ($pathNotFound);}sub getPath{(my $command
=shift (@_));(my $ref_commandPath=getReferenceToSavedCommand ($command));if ((
not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath ($command));}(my $commandPath
=$$ref_commandPath);return ($commandPath);}sub getCommand{(my (@args)=@_);(my $command
=shift (@args));(my $ref_commandPath=getReferenceToSavedCommand ($command));if (
(not (defined ($$ref_commandPath)))){($$ref_commandPath=checkPath ($command));}(my $commandPath
=$$ref_commandPath);(my (@reply)=());if (($commandPath ne $pathNotFound)){push (
@reply,$commandPath,@args);}else{push (@reply,$GLOBAL::CommandBash,
"\x2d\x2d\x6c\x6f\x67\x69\x6e","\x2d\x63",main::shell_quote ($command,@args));}
return (@reply);}sub getReferenceToSavedCommand{(my $command=shift (@_));(my $refCommand
=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command)."\x5f\x63\x6f\x6d\x6d\x61\x6e\x64"));return ($refCommand);}sub 
getReferenceToSavedCommandParameters{(my $command=shift (@_));(my $type=shift (
@_));(my $refOptions=((
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x68\x65\x6c\x6c\x43\x6f\x6d\x6d\x61\x6e\x64\x73\x3a\x3a"
.$command).("\x5f\x6f\x70\x74\x69\x6f\x6e\x73\x5f".$type)));return ($refOptions)
;}sub isApplicationInKnownPath{(my $command=shift (@_));(my $refCommand=
getReferenceToSavedCommand ($command));if ((not (defined ($$refCommand)))){(
$$refCommand=checkPath ($command));}(my $commandPath=$$refCommand);if ((
$commandPath ne $pathNotFound)){return ((0x11f6+ 3854-0x2103));}return (
(0x0eba+ 5595-0x2495));}sub isPasswordRequestMessage{(my $message=shift (@_));if
 ((((($message=~ /password for/ )or ($message=~ /Password/ ))or ($message=~ /'s password/ )
)or ($message=~ /assword:\ *$/ ))){return ((0x19db+ 613-0x1c3f));}return (
(0x0680+ 7035-0x21fb));}sub isNotInSudoersMessage{(my $message=shift (@_));if ((
($message=~ /is not in the sudoers file/ )or ($message=~ /is not allowed to execute/ )
)){return ((0x13b4+ 1101-0x1800));}return ((0x0ba7+ 2038-0x139d));}sub 
isNotAdministrator{(my $message=shift (@_));if (($message=~ /Only a user with administrative privileges can use option/ )
){return ((0x0384+ 5269-0x1818));}return ((0x05e4+ 1471-0x0ba3));}sub 
getConnectionsForXserversCheck{(my $ref_cmd_out=shift (@_));(my $ref_exit_value=
shift (@_));(my (@command)=getNetStatisticsCommandForListeningUnix ());if ((
$command[(0x0507+ 5493-0x1a7c)]eq $pathNotFound)){($$ref_exit_value=
(0x0ef8+ 1694-0x1595));return ((0x03b5+ 1707-0x0a60));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x27"
.$$ref_exit_value)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x6f\x75\x74\x70\x75\x74\x20\x27"
.$$ref_cmd_out)."\x27\x2e"));Logger::warning (((
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x27"
.$cmd_err)."\x27\x2e"));return ((0x0395+ 2195-0x0c28));}return (
(0x1041+ 4695-0x2297));}sub getListeningConnections{(my $ref_cmd_out=shift (@_))
;(my $ref_exit_value=shift (@_));(my (@command)=getNetStatisticsCommandForAllTcp
 ());if (($command[(0x020b+ 9418-0x26d5)]eq $pathNotFound)){($$ref_exit_value=
(0x0758+ 2717-0x11f4));return ((0x0b71+ 6777-0x25ea));}my ($cmd_err);(($cmd_err,
$$ref_cmd_out,$$ref_exit_value)=main::run_command ((\@command),("")));if (
$$ref_exit_value){return ((0x06f2+ 1840-0x0e22));}return ((0x1b75+ 1786-0x226e))
;}sub getExtendedListeningConnectionsForFontServerChecking{(my $ref_cmd_out=
shift (@_));(my $ref_exit_value=shift (@_));(my (@command)=
getNetStatisticsCommandForListeningTcpExtended ());if (($command[
(0x013a+ 5789-0x17d7)]eq $pathNotFound)){($$ref_exit_value=(0x0e17+ 5139-0x2229)
);return ((0x073a+ 1645-0x0da7));}my ($cmd_err);(($cmd_err,$$ref_cmd_out,
$$ref_exit_value)=main::run_command ((\@command),("")));if ($$ref_exit_value){
return ((0x0de9+ 2018-0x15cb));}return ((0x12f2+ 1424-0x1881));}sub 
getNetStatisticsComandWithPrioritySs{(my $commandPath=checkPath ("\x73\x73"));if
 (($commandPath eq $pathNotFound)){($commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsNetstat ();}
}else{setNetStatisticsCommandIsSs ();}return ($commandPath);}sub 
getNetStatisticsComandWithPriorityNetstat{(my $commandPath=checkPath (
"\x6e\x65\x74\x73\x74\x61\x74"));if (($commandPath eq $pathNotFound)){(
$commandPath=checkPath ("\x73\x73"));if (($commandPath eq $pathNotFound)){
setNetStatisticsCommandIsNotFound ();}else{setNetStatisticsCommandIsSs ();}}else
{setNetStatisticsCommandIsNetstat ();}return ($commandPath);}sub 
setNetStatisticsCommand{(my $command=
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73");if (
isNetStatisticsCommandSet ()){return;}(my $ref_commandPath=
getReferenceToSavedCommand ($command));if (
Common::NXInfo::doesOsPreferSsOverNetstat ()){($$ref_commandPath=
getNetStatisticsComandWithPrioritySs ());}else{($$ref_commandPath=
getNetStatisticsComandWithPriorityNetstat ());}}sub 
getNetStatisticsCommandForListeningUnix{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e",
"\x2d\x2d\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d\x75\x6e\x69\x78"));}if (
isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6c\x6e\x78"));}
return ($pathNotFound);}sub getNetStatisticsCommandForAllTcp{
setNetStatisticsCommand ();return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x61\x6e\x74"));}sub
 getNetStatisticsCommandForListeningTcpExtended{setNetStatisticsCommand ();if (
isNetStatisticsCommandNetstat ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x65\x74\x6c"));
}if (isNetStatisticsCommandSs ()){return (getCommand (
"\x6e\x65\x74\x53\x74\x61\x74\x69\x73\x74\x69\x63\x73","\x2d\x6e\x74\x6c"));}
return ($pathNotFound);}sub isNetStatisticsCommandSet{if (defined (
$netStatisticsCommand)){return ((0x05cd+ 581-0x0811));}return (
(0x07b0+ 6535-0x2137));}sub setNetStatisticsCommandIsNotFound{Logger::warning (
"\x43\x6f\x6d\x6d\x61\x6e\x64\x20\x66\x6f\x72\x20\x6e\x65\x74\x20\x73\x74\x61\x74\x69\x73\x74\x69\x63\x73\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e"
);($netStatisticsCommand=$pathNotFound);}sub setNetStatisticsCommandIsSs{(
$netStatisticsCommand=$commandSs);}sub setNetStatisticsCommandIsNetstat{(
$netStatisticsCommand=$commandNetstat);}sub isNetStatisticsCommandNetstat{if ((
$netStatisticsCommand eq $commandNetstat)){return ((0x0096+ 878-0x0403));}return
 ((0x0860+ 6520-0x21d8));}sub isNetStatisticsCommandSs{if ((
$netStatisticsCommand eq $commandSs)){return ((0x099c+ 5113-0x1d94));}return (
(0x00e7+ 1595-0x0722));}sub isNetStatisticsCommandAvailable{
setNetStatisticsCommand ();if (($netStatisticsCommand eq $pathNotFound)){return 
((0x02f2+ 4448-0x1452));}return ((0x14eb+ 2117-0x1d2f));}sub 
isDbusDaemonCommandAvailable{(my $dbusDaemonPath=getPath (
"\x64\x62\x75\x73\x2d\x64\x61\x65\x6d\x6f\x6e"));if (($dbusDaemonPath eq 
$pathNotFound)){return ((0x12d1+ 4231-0x2358));}return ((0x10cb+ 5392-0x25da));}
sub isDbusSendCommandAvailable{(my $dbusSendPath=getPath (
"\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));if (($dbusSendPath eq $pathNotFound)){
return ((0x0599+ 3528-0x1361));}return ((0x0114+ 5707-0x175e));}sub 
isNotDbusSendCommandAvailable{return ((!isDbusSendCommandAvailable ()));}sub 
getDbusSendCommand{return (getPath ("\x64\x62\x75\x73\x2d\x73\x65\x6e\x64"));}
"\x3f\x3f\x3f";
